@@ -17,6 +17,14 @@ bom_patterns = [
     path('bom-signup/', views.bom_signup, name='bom-signup'),
     path('settings/', views.bom_settings, name='settings'),
     path('settings/<str:tab_anchor>/', views.bom_settings, name='settings'),
+    path('manufacturers/', views.manufacturers, name='manufacturers'),
+    path('manufacturer/<int:manufacturer_id>/', views.manufacturer_info, name='manufacturer-info'),
+    path('manufacturer/<int:manufacturer_id>/edit/', views.manufacturer_edit, name='manufacturer-edit'),
+    path('manufacturer/<int:manufacturer_id>/delete/', views.manufacturer_delete, name='manufacturer-delete'),
+    path('sellers/', views.sellers, name='sellers'),
+    path('seller/<int:seller_id>/', views.seller_info, name='seller-info'),
+    path('seller/<int:seller_id>/edit/', views.seller_edit, name='seller-edit'),
+    path('seller/<int:seller_id>/delete/', views.seller_delete, name='seller-delete'),
     path('export/', views.export_part_list, name='export-part-list'),
     path('user-meta/<int:user_meta_id>/edit/', views.user_meta_edit, name='user-meta-edit'),
     path('part-class/<int:part_class_id>/edit/', views.part_class_edit, name='part-class-edit'),
